Effect

Enum Effect 

pub enum Effect {
    And(Vec<Effect>),
    Predicate(AtomicFormula),
    NotPredicate(AtomicFormula),
    Forall {
        variables: TypedList<Variable>,
        effect: Box<Effect>,
    },
    When {
        condition: Condition,
        effect: Box<Effect>,
    },
    NumericAssign {
        op: AssignOp,
        function: FunctionTerm,
        expr: NumericExpr,
    },
    AtStart(Box<Effect>),
    AtEnd(Box<Effect>),
}
An action effect.

Effects can add/delete predicate instances, perform numeric assignments, and include conditional (when) and universal (forall) sub-effects. Inside durative actions, effects are wrapped in temporal markers (AtStart, AtEnd).

Variants



And(Vec<Effect>)

Conjunction: (and e1 e2 ...).



Predicate(AtomicFormula)

Add (assert) a predicate instance.



NotPredicate(AtomicFormula)

Delete (negate) a predicate instance: (not (pred ...)).



Forall

Universal effect: (forall (?x - type) <effect>).

Fields

variables: TypedList<Variable>
effect: Box<Effect>


When

Conditional effect: (when <condition> <effect>).

Fields

condition: Condition
effect: Box<Effect>


NumericAssign

Numeric assignment: (assign/increase/decrease/scale-up/scale-down <fn> <expr>).

Fields

function: FunctionTerm


AtStart(Box<Effect>)

(at start <effect>).



AtEnd(Box<Effect>)

(at end <effect>).