pub fn parse_domain(tokens: &[Token]) -> Result<Domain, ParseError>Expand description
Parse a pre-tokenized PDDL domain.
Prefer parse_domain_str unless you need to inspect or reuse the token stream.
Arguments
tokens- Token stream produced bycrate::lexer::tokenize
Returns
A Domain AST on success.
Errors
Returns ParseError if the token stream does not represent a valid PDDL domain.