parse_problem

Function parse_problem 

pub fn parse_problem(tokens: &[Token]) -> Result<Problem, ParseError>
Parse a pre-tokenized PDDL problem.

Prefer parse_problem_str unless you need to inspect or reuse the token stream.

Arguments

Returns

A Problem AST on success.

Errors

Returns ParseError if the token stream does not represent a valid PDDL problem.