pub fn parse_problem(tokens: &[Token]) -> Result<Problem, ParseError>Expand description
Parse a pre-tokenized PDDL problem.
Prefer parse_problem_str unless you need to inspect or reuse the token stream.
Arguments
tokens- Token stream produced bycrate::lexer::tokenize
Returns
A Problem AST on success.
Errors
Returns ParseError if the token stream does not represent a valid PDDL problem.